//----------------------------------------------------------------------------------------
// Frame protocol
//----------------------------------------------------------------------------------------

#ifndef _CREDITNOWDEMO_
#include "CPCreditNowDemo.h"
#endif

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::DisplayFrameAdded(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_DisplayFrameAdded
	EnteringMethod("\pCPCreditNowDemo::AddDisplayFrame");

	fDisplayFrames.Add(frame);
		// Add new frame to list of current display frames.
	
	frame->SetDroppable(ev, kODTrue);
		// We always want drag and drop in parts.
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::DisplayFrameConnected(Environment* ev, ODFrame* /*frame*/)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_DisplayFrameConnected
	EnteringMethod("\pCPCreditNowDemo::DisplayFrameConnected");

	// // fDisplayFrames.Add(frame);
	// Don't need to add frame to list of current display frames because we already did
	// in InitPartFromStorage.
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::DisplayFrameRemoved(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_DisplayFrameRemoved
	EnteringMethod("\pCPCreditNowDemo::DisplayFrameRemoved");

	fSession->GetArbitrator(ev)->RelinquishFocusSet(ev, fFocusSet, frame);

	fDisplayFrames.Remove(frame);
		// This just removes the reference from our frame list.
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::DisplayFrameClosed(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_DisplayFrameClosed
	EnteringMethod("\pCPCreditNowDemo::DisplayFrameClosed");

	fSession->GetArbitrator(ev)->RelinquishFocusSet(ev, fFocusSet, frame);

	fDisplayFrames.Remove(frame);
		// This just removes the reference from our frame list.
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::FrameShapeChanged(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_FrameShapeChanged
	EnteringMethod("\pCPCreditNowDemo::FrameShapeChanged");

	frame->RequestFrameShape(ev, this->PrivGetFrameShape(ev, frame), kODNULL);
	this->PrivAdjustFacets(ev, frame);
	frame->Invalidate(ev, kODNULL, kODNULL);
	frame->InvalidateActiveBorder(ev);
}

//----------------------------------------------------------------------------------------

ODShape* CPCreditNowDemo::PrivGetFrameShape(Environment* ev, ODFrame* frame)
{
	// This is just to centralize the frame shape code.  Do it any way
	// is best for your part.

	ODShape* newFrameShape;

	if (frame->IsRoot(ev))
		newFrameShape = frame->GetFrameShape(ev, kODNULL);
	else
		newFrameShape = this->PrivGetUsedShape(ev, frame);

	return newFrameShape;
}

//----------------------------------------------------------------------------------------

ODShape* CPCreditNowDemo::PrivGetUsedShape(Environment* ev, ODFrame* frame)
{
	// This is just to centralize the frame shape code.  Do it any way
	// is best for your part.
	
	ODShape* frameShape = frame->GetFrameShape(ev, kODNULL);
	RgnHandle	shapeRgn = frameShape->GetQDRegion(ev);
	Rect		rr;

	frameShape->Release(ev);

	ODTypeToken	theViewType = frame->GetViewType(ev);
		
	// handle Small Icon view
	if (theViewType == fSession->Tokenize(ev, kODViewAsSmallIcon))
	{
		::SetRect(&rr, 0, 0, kODSmallIconSize, kODSmallIconSize);
	}
	// handle Large Icon view
	else if (theViewType == fSession->Tokenize(ev, kODViewAsLargeIcon))
	{
		::SetRect(&rr, 0, 0, kODLargeIconSize, kODLargeIconSize);
	}
	// handle Thumbnail view
	else if (theViewType == fSession->Tokenize(ev, kODViewAsThumbnail))
	{
		::SetRect(&rr, 0, 0, kODThumbnailSize, kODThumbnailSize);
	}
	// handle Frame viewType
	else
	{
//AET<<
		::SetRect(&rr, 0, 0, 320, 255);
//AET>>
	}

//AET<<
	::OpenRgn();
	::FrameRoundRect(&rr, 40, 40);
	::CloseRgn(shapeRgn = ::NewRgn());
//AET>>

	ODShape* usedShape = frame->CreateShape(ev);
	usedShape->SetQDRegion(ev, shapeRgn);

	return usedShape;
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::PrivAdjustFacets(Environment* ev, ODFrame* frame)
{
	// Given a frame, iterate through all of the facets and adjust them
	// according to the new frame.

	ODShape* usedShape  = this->PrivGetUsedShape(ev, frame);
	frame->ChangeUsedShape(ev, usedShape, kODNULL);
	usedShape->Release(ev);

	ODShape* frameShape = frame->GetFrameShape(ev, kODNULL);
	ODFrameFacetIterator* facets = frame->CreateFacetIterator(ev);
	for (ODFacet* facet = facets->First(ev);
			facets->IsNotComplete(ev);
			facet = facets->Next(ev) )
	{
		facet->ChangeActiveShape(ev, frameShape, kODNULL);
	}
	frameShape->Release(ev);
}


//----------------------------------------------------------------------------------------

void CPCreditNowDemo::AttachSourceFrame(Environment* ev, ODFrame* frame, ODFrame* sourceFrame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_AttachSourceFrame
	EnteringMethod("\pCPCreditNowDemo::AttachSourceFrame");
	ODUnused(frame);
	ODUnused(sourceFrame);
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::ViewTypeChanged(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_ViewTypeChanged
	EnteringMethod("\pCPCreditNowDemo::ViewTypeChanged");

	// Invalidate the entire frame
	frame->Invalidate(ev, kODNULL, kODNULL);
	frame->InvalidateActiveBorder(ev);
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::PresentationChanged(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_PresentationChanged
	EnteringMethod("\pCPCreditNowDemo::PresentationChanged");
	ODUnused(frame);
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::SequenceChanged(Environment* ev, ODFrame* frame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_SequenceChanged
	EnteringMethod("\pCPCreditNowDemo::SequenceChanged");
	ODUnused(frame);
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::WritePartInfo(Environment* ev, ODInfoType partInfo,
							   ODStorageUnitView* storageUnitView)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_WritePartInfo
	EnteringMethod("\pCPCreditNowDemo::WritePartInfo");
	ODUnused(partInfo);
	ODUnused(storageUnitView);
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::ClonePartInfo(Environment *ev, ODDraftKey key,
								ODInfoType partInfo,
								ODStorageUnitView* storageUnitView,
								ODFrame* scopeFrame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_ClonePartInfo
	EnteringMethod("\pCPCreditNowDemo::ClonePartInfo");
	ODUnused(key);
	ODUnused(partInfo);
	ODUnused(storageUnitView);
	ODUnused(scopeFrame);
}

//----------------------------------------------------------------------------------------

ODInfoType CPCreditNowDemo::ReadPartInfo(Environment* ev, ODFrame* frame, ODStorageUnitView* storageUnitView)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_ReadPartInfo
	EnteringMethod("\pCPCreditNowDemo::ReadPartInfo");
	ODUnused(frame);
	ODUnused(storageUnitView);
	return kODNULL;
}

//----------------------------------------------------------------------------------------

ODFrame* CPCreditNowDemo::RequestEmbeddedFrame(Environment* ev, ODFrame* containingFrame,
										   ODFrame* baseFrame,
										   ODShape* frameShape,
										   ODPart* embedPart,
										   ODTypeToken viewType,
										   ODTypeToken presentation,
										   ODBoolean isOverlaid)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_RequestEmbeddedFrame
	EnteringMethod("\pCPCreditNowDemo::RequestEmbeddedFrame");
	ODUnused(containingFrame);
	ODUnused(baseFrame);
	ODUnused(frameShape);
	ODUnused(embedPart);
	ODUnused(viewType);
	ODUnused(presentation);
	ODUnused(isOverlaid);
	DebugStr("\pCPCreditNowDemo::RequestEmbeddedFrame -- shouldn't be here.");
	return kODNULL;
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::RemoveEmbeddedFrame(Environment* ev, ODFrame* embeddedFrame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_RemoveEmbeddedFrame
	EnteringMethod("\pCPCreditNowDemo::RemoveEmbeddedFrame");
	ODUnused(embeddedFrame);
	DebugStr("\pCPCreditNowDemo::RemoveEmbeddedFrame -- shouldn't be here.");
}

//----------------------------------------------------------------------------------------

ODShape* CPCreditNowDemo::RequestFrameShape(Environment* ev, ODFrame* embeddedFrame, ODShape* frameShape)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_RequestFrameShape
	EnteringMethod("\pCPCreditNowDemo::RequestFrameShape");
	ODUnused(embeddedFrame);
	ODUnused(frameShape);
	DebugStr("\pCPCreditNowDemo::RequestFrameShape -- shouldn't be here.");
	return kODNULL;
}

//----------------------------------------------------------------------------------------

void CPCreditNowDemo::UsedShapeChanged(Environment* ev, ODFrame* embeddedFrame)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_UsedShapeChanged
	EnteringMethod("\pCPCreditNowDemo::UsedShapeChanged");
	ODUnused(embeddedFrame);
}

//----------------------------------------------------------------------------------------

ODShape* CPCreditNowDemo::AdjustBorderShape(Environment* ev, ODFacet* embeddedFacet, ODShape* shape)
{
	// CodeWarrior: Cmd-Click or Search:Find Definition  Explain_AdjustBorderShape
	EnteringMethod("\pCPCreditNowDemo::AdjustBorderShape");
	ODUnused(embeddedFacet);
	return shape;
}
